ChemInventory
=================

![pypiBadge](https://img.shields.io/pypi/v/ChemInventory)


An unofficial python SDK for [ChemInventory](https://www.cheminventory.net/)

Usage
-----

```python

ci = ChemInventory(email='joe@none.com', password='123456')
#Search for a CAS number
ci.search('75-65-0')
```

Installation
------------

`pip install cheminventory``


Authors
-------

This is an unofficial cheminventory package  written by `Kobi Felton <kobi.c.f@gmail.com>`_.
